@@ -9,6 +9,7 @@ from . import typings
 from .software_version import SoftwareVersion
 from .exceptions import CredentialsInvalidError, SnapshotIsNotValidFileTypeError, InvalidContentTypeError
 import traceback
+import re
 
 import asyncio
 import aiohttp
@@ -107,6 +108,7 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         self._ptz_support = False
 
         self._is_nvr = False
+        self._is_ia_enabled = False
 
         self._aiohttp_session: aiohttp.ClientSession = aiohttp.ClientSession(timeout=self._timeout,
                                                                              connector=aiohttp.TCPConnector(verify_ssl=False))
@@ -133,6 +135,11 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         """Return the port."""
         return self._port
 
+    @property
+    def is_ia_enabled(self):
+        """Wether or not the camera support IA"""
+        return self._is_ia_enabled
+
     @property
     def onvif_port(self):
         """Return the onvif port for subscription."""
@@ -533,6 +540,8 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                     self._channels = data["value"]["DevInfo"]["channelNum"]
                     self._sw_version_object = SoftwareVersion(self._sw_version)
                     self._is_nvr = data["value"]["DevInfo"].get("exactType", "CAM") == "NVR"
+                    if re.compile(r"^RLC-([0-9]+)A$").match(self._model) is not None:
+                        self._is_ia_enabled = True
 
                 elif data["cmd"] == "GetHddInfo":
                     self._hdd_info = data["value"]["HddInfo"]
@@ -591,7 +600,7 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                 elif data["cmd"] == "GetRecV20":
                     self._recording_settings = data
                     self._recording_state = (
-                            data["value"]["Rec"]["schedule"]["enable"] == 1
+                            data["value"]["Rec"]["enable"] == 1
                     )
                 elif data["cmd"] == "GetPtzPreset":
                     self._ptz_presets_settings = data
@@ -857,10 +866,16 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         else:
             new_value = 0
 
-        body = [
-            {"cmd": "SetRec", "action": 0, "param": self._recording_settings["value"]}
-        ]
-        body[0]["param"]["Rec"]["schedule"]["enable"] = new_value
+        if self._recording_settings["value"]["Rec"].get("enable") is not None:
+            body = [
+                {"cmd": "SetRecV20", "action": 0, "param": self._recording_settings["value"]}
+            ]
+            body[0]["param"]["Rec"]["enable"] = new_value
+        else:
+            body = [
+                {"cmd": "SetRec", "action": 0, "param": self._recording_settings["value"]}
+            ]
+            body[0]["param"]["Rec"]["schedule"]["enable"] = new_value
 
         return await self.send_setting(body)
 
